@@ -1,7 +1,7 @@
 context("nodeSub_sim_normal_explicit")
 
 test_that("sim_normal_explicit", {
-  phy  <- phytools::read.newick(text = "(t1:10,(t3:2,t2:2):8);")
+  phy  <- ape::read.tree(text = "(t1:10,(t3:2,t2:2):8);")
   set.seed(43) # for reproducability
   seq_implicit <- sim_normal(x = phy, l = 10000,  rate = 0.01)
   seq_explicit <- sim_normal_explicit(x = phy, l = 10000, rate = 0.01,
