@@ -3,7 +3,9 @@ context("sim_unlinked_explicit")
 test_that("sim_unlinked_explicit", {
   phy  <- ape::read.tree(text = "(t1:10,(t3:2,t2:2):8);")
 
-  sequences <- nodeSub::sim_unlinked(phy, node_time = 0.1, rate1 = 0.01, rate2 = 0.01)
+  sequences <- nodeSub::sim_unlinked(phy, node_time = 0.1,
+                                     rate1 = 0.01,
+                                     rate2 = 0.01)
   testthat::expect_true(class(sequences$alignment) == "phyDat")
 
   sequences_2 <- nodeSub::sim_unlinked_explicit(phy = phy,
